Index: uspace/lib/libc/generic/async.c
===================================================================
--- uspace/lib/libc/generic/async.c	(revision d9c8c81f21850cb9e08890ce3919e1d8e253e810)
+++ uspace/lib/libc/generic/async.c	(revision cc27c8c5e6462ab97fd46b844e8591be59e37ac6)
@@ -551,7 +551,8 @@
 	/* Answer all remaining messages with EHANGUP */
 	while (!list_empty(&FIBRIL_connection->msg_queue)) {
-		msg_t *msg
-		    = list_get_instance(FIBRIL_connection->msg_queue.next, msg_t, link);
-		
+		msg_t *msg;
+		
+		msg = list_get_instance(FIBRIL_connection->msg_queue.next,
+		    msg_t, link);
 		list_remove(&msg->link);
 		ipc_answer_0(msg->callid, EHANGUP);
@@ -718,6 +719,6 @@
 		suseconds_t timeout;
 		if (!list_empty(&timeout_list)) {
-			awaiter_t *waiter
-			    = list_get_instance(timeout_list.next, awaiter_t, link);
+			awaiter_t *waiter = list_get_instance(timeout_list.next,
+			    awaiter_t, link);
 			
 			struct timeval tv;
@@ -736,6 +737,6 @@
 		
 		ipc_call_t call;
-		ipc_callid_t callid
-		    = ipc_wait_cycle(&call, timeout, SYNCH_FLAGS_NONE);
+		ipc_callid_t callid = ipc_wait_cycle(&call, timeout,
+		    SYNCH_FLAGS_NONE);
 		
 		if (!callid) {
Index: uspace/lib/libc/generic/fibril.c
===================================================================
--- uspace/lib/libc/generic/fibril.c	(revision d9c8c81f21850cb9e08890ce3919e1d8e253e810)
+++ uspace/lib/libc/generic/fibril.c	(revision cc27c8c5e6462ab97fd46b844e8591be59e37ac6)
@@ -50,5 +50,6 @@
 #endif
 
-/** This futex serializes access to ready_list, serialized_list and manage_list.
+/**
+ * This futex serializes access to ready_list, serialized_list and manager_list.
  */ 
 static atomic_t fibril_futex = FUTEX_INITIALIZER;
@@ -60,10 +61,10 @@
 static void fibril_main(void);
 
-/** Number of fibrils that are in async_serialized mode */
-static int serialized_fibrils;	/* Protected by async_futex */
-/** Thread-local count of serialization. If >0, we must not preempt */
+/** Number of threads that are executing a manager fibril. */
+static int threads_in_manager;
+/** Number of threads that are executing a manager fibril and are serialized. */
+static int serialized_threads;	/* Protected by async_futex */
+/** Thread-local count of serialization. If > 0, we must not preempt */
 static __thread int serialization_count;
-/** Counter for fibrils residing in async_manager */
-static int fibrils_in_manager;
 
 /** Setup fibril information into TCB structure */
@@ -144,9 +145,9 @@
 			goto ret_0;
 		/*
-		 * Do not preempt if there is not sufficient count of fibril 
-		 * managers.
+		 * Do not preempt if there is not enough threads to run the
+		 * ready fibrils, which are not serialized.
 		 */
 		if (list_empty(&serialized_list) &&
-		    fibrils_in_manager <= serialized_fibrils) {
+		    threads_in_manager <= serialized_threads) {
 			goto ret_0;
 		}
@@ -195,5 +196,5 @@
 		else if (stype == FIBRIL_FROM_MANAGER) {
 			list_append(&srcf->link, &manager_list);
-			fibrils_in_manager--;
+			threads_in_manager--;
 		} else {	
 			/*
@@ -209,8 +210,8 @@
 		dstf = list_get_instance(manager_list.next, fibril_t, link);
 		if (serialization_count && stype == FIBRIL_TO_MANAGER) {
-			serialized_fibrils++;
+			serialized_threads++;
 			srcf->flags |= FIBRIL_SERIALIZED;
 		}
-		fibrils_in_manager++;
+		threads_in_manager++;
 
 		if (stype == FIBRIL_FROM_DEAD) 
@@ -220,5 +221,5 @@
 			dstf = list_get_instance(serialized_list.next, fibril_t,
 			    link);
-			serialized_fibrils--;
+			serialized_threads--;
 		} else {
 			dstf = list_get_instance(ready_list.next, fibril_t,
@@ -270,5 +271,5 @@
 /** Add a fibril to the ready list.
  *
- * @param fid		Pinter to the fibril structure of the fibril to be
+ * @param fid		Pointer to the fibril structure of the fibril to be
  *			added.
  */
@@ -288,5 +289,6 @@
 /** Add a fibril to the manager list.
  *
- * @param fid		Pinter to the fibril structure of the fibril to be added.
+ * @param fid		Pointer to the fibril structure of the fibril to be
+ *			added.
  */
 void fibril_add_manager(fid_t fid)
@@ -315,5 +317,5 @@
 /** Return fibril id of the currently running fibril.
  *
- * @return		Fibril ID of the currently running pseudo thread.
+ * @return		Fibril ID of the currently running fibril.
  */
 fid_t fibril_get_id(void)
